from pydantic import BaseModel, SecretStr
from pydantic_settings import BaseSettings


class DatabaseModel(BaseModel):
    sqlite_file: str

    @property
    def dsn(self):
        return f"sqlite:////{self.sqlite_file}"

    @property
    def async_dsn(self):
        return f"sqlite+aiosqlite:////{self.sqlite_file}"

    model_config = {"extra": "allow"}


class LivekitModel(BaseModel):
    api_key: SecretStr
    api_secret: SecretStr
    url: str


class OpenrouterModel(BaseModel):
    api_key: SecretStr
    model: str


class GroqModel(BaseModel):
    api_key: SecretStr
    model: str | None = None


class ElevenlabsModel(BaseModel):
    api_key: SecretStr
    voice_id: str


class Settings(BaseSettings):
    db: DatabaseModel
    livekit: LivekitModel
    openrouter: OpenrouterModel
    groq: GroqModel
    elevenlabs: ElevenlabsModel

    model_config = {
        "env_file": ".env",
        "env_file_encoding": "utf-8",
        "env_nested_delimiter": "__",
    }


settings = Settings()
